==> zio-aws-auditmanager_3-5.17.130.3-sources.jar: zio/aws/auditmanager/model/CreateAssessmentReportResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateAssessmentReportResponse(
    assessmentReport: Option[zio.aws.auditmanager.model.AssessmentReport] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse = {
    import CreateAssessmentReportResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
      .builder()
      .optionallyWith(assessmentReport.map(value => value.buildAwsValue()))(
        _.assessmentReport
      )
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly =
    zio.aws.auditmanager.model.CreateAssessmentReportResponse
      .wrap(buildAwsValue())
}
object CreateAssessmentReportResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.CreateAssessmentReportResponse =
      zio.aws.auditmanager.model.CreateAssessmentReportResponse(
        assessmentReport.map(value => value.asEditable)
      )
    def assessmentReport
        : Option[zio.aws.auditmanager.model.AssessmentReport.ReadOnly]
    def getAssessmentReport: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.AssessmentReport.ReadOnly
    ] = AwsError.unwrapOptionField("assessmentReport", assessmentReport)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ) extends zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly {
    override val assessmentReport
        : Option[zio.aws.auditmanager.model.AssessmentReport.ReadOnly] = scala
      .Option(impl.assessmentReport())
      .map(value => zio.aws.auditmanager.model.AssessmentReport.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ): zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-auditmanager_3-6.20.149.2-sources.jar: zio/aws/auditmanager/model/CreateAssessmentReportResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateAssessmentReportResponse(
    assessmentReport: Optional[zio.aws.auditmanager.model.AssessmentReport] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse = {
    import CreateAssessmentReportResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
      .builder()
      .optionallyWith(assessmentReport.map(value => value.buildAwsValue()))(
        _.assessmentReport
      )
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly =
    zio.aws.auditmanager.model.CreateAssessmentReportResponse
      .wrap(buildAwsValue())
}
object CreateAssessmentReportResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.CreateAssessmentReportResponse =
      zio.aws.auditmanager.model.CreateAssessmentReportResponse(
        assessmentReport.map(value => value.asEditable)
      )
    def assessmentReport
        : Optional[zio.aws.auditmanager.model.AssessmentReport.ReadOnly]
    def getAssessmentReport: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.AssessmentReport.ReadOnly
    ] = AwsError.unwrapOptionField("assessmentReport", assessmentReport)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ) extends zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly {
    override val assessmentReport
        : Optional[zio.aws.auditmanager.model.AssessmentReport.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.assessmentReport())
        .map(value => zio.aws.auditmanager.model.AssessmentReport.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.CreateAssessmentReportResponse
  ): zio.aws.auditmanager.model.CreateAssessmentReportResponse.ReadOnly =
    new Wrapper(impl)
}
